/* confdefs.h */
#define PACKAGE_NAME "gaselect"
#define PACKAGE_TARNAME "gaselect"
#define PACKAGE_VERSION "1.0.7"
#define PACKAGE_STRING "gaselect 1.0.7"
#define PACKAGE_BUGREPORT ""
#define PACKAGE_URL ""
#define STDC_HEADERS 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_MEMORY_H 1
#define HAVE_STRINGS_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_STDINT_H 1
#define HAVE_UNISTD_H 1
#define HAVE_STDINT_H 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIMITS_H 1
#define HAVE_CLIMITS 1
#define HAVE_UNSIGNED_LONG_LONG 1
#define HAVE_UINT8_16_MAX 1
#define HAVE_UINT8_16_MAX 1
#define HAVE_GCC_CTZL 1
#define HAVE_GCC_CTZLL 1
#define HAVE_FFSL 1
#define HAVE_BUILTIN_POPCOUNTL 1
#define HAVE_BUILTIN_POPCOUNTLL 1
#define HAVE_PTHREAD_H 1
